@@ -30,10 +30,9 @@ public:
         , delay(false)
         , m_engine(engine)
     {
-        executionEndTimer = new QTimer(q);
-        executionEndTimer->setInterval(0);
-        executionEndTimer->setSingleShot(true);
-        QObject::connect(executionEndTimer, &QTimer::timeout, q, [this]() {
+        executionEndTimer.setInterval(0);
+        executionEndTimer.setSingleShot(true);
+        QObject::connect(&executionEndTimer, &QTimer::timeout, q, [this]() {
             scheduleExecutionEnd();
         });
     }
@@ -60,7 +59,7 @@ public:
 
     QQmlIncubator incubator;
     QQmlComponent *component;
-    QTimer *executionEndTimer;
+    QTimer executionEndTimer;
     KLocalizedContext *context{nullptr};
     QQmlContext *rootContext;
     bool delay;
@@ -91,7 +90,7 @@ void SharedQmlEnginePrivate::execute(const QUrl &source)
     component->loadUrl(source);
 
     if (delay) {
-        executionEndTimer->start(0);
+        executionEndTimer.start(0);
     } else {
         scheduleExecutionEnd();
     }
@@ -160,7 +159,7 @@ std::shared_ptr<QQmlEngine> SharedQmlEngine::engine()
 QObject *SharedQmlEngine::rootObject() const
 {
     if (d->incubator.status() == QQmlIncubator::Loading) {
-        qWarning() << "Trying to use rootObject before initialization is completed, whilst using setInitializationDelayed. Forcing completion";
+        qCWarning(KCMUTILS_LOG) << "Trying to use rootObject before initialization is completed, whilst using setInitializationDelayed. Forcing completion";
         d->incubator.forceCompletion();
     }
     return d->incubator.object();
@@ -186,7 +185,7 @@ QQmlComponent::Status SharedQmlEngine::status() const
         return QQmlComponent::Null;
     }
 
-    return QQmlComponent::Status(d->component->status());
+    return d->component->status();
 }
 
 void SharedQmlEnginePrivate::checkInitializationCompleted()
@@ -207,13 +206,13 @@ void SharedQmlEnginePrivate::checkInitializationCompleted()
 
 void SharedQmlEngine::completeInitialization(const QVariantMap &initialProperties)
 {
-    d->executionEndTimer->stop();
+    d->executionEndTimer.stop();
     if (d->incubator.object()) {
         return;
     }
 
     if (!d->component) {
-        qWarning() << "No component for" << source();
+        qCWarning(KCMUTILS_LOG) << "No component for" << source();
         return;
     }
 
